pub struct Device(/* private fields */);Expand description
The Device implementation associated with the platform’s dynamically dispatched
Host type.
Implementations
Sourceimpl Device
impl Device
Sourcepub fn as_inner(&self) -> &DeviceInner
pub fn as_inner(&self) -> &DeviceInner
Returns a reference to the underlying platform specific implementation of this
Device.
Sourcepub fn as_inner_mut(&mut self) -> &mut DeviceInner
pub fn as_inner_mut(&mut self) -> &mut DeviceInner
Returns a mutable reference to the underlying platform specific implementation of
this Device.
Sourcepub fn into_inner(self) -> DeviceInner
pub fn into_inner(self) -> DeviceInner
Returns the underlying platform specific implementation of this Device.